Learn R Programming

EvalEst (version 2015.4-2)

coef.TSmodelEstEval: Specific Methods for coef

Description

See the generic function description.

Usage

"coef"(object, criterion.args=NULL, ...) "coef"(object, criterion.args=NULL, ...)

Arguments

object
an object (model) from which to extract coefficients(parameters).
criterion.args
arguments to be passed to this method when it is called by EstEval.
...
(further arguments, currently disregarded).

Details

The methods ***.ee are intended mainly to be called from EstEval as criterion for evaluating an estimation method. See coef.

See Also

EstEval coef