Learn R Programming

EvalEst (version 2012.4-1)

roots.coefEstEval: Roots Specific Methods

Description

See the generic function description.

Usage

## S3 method for class 'coefEstEval':
roots(obj, criterion.args=NULL, ...)
    ## S3 method for class 'rootsEstEval':
roots(obj, ...)
    ## S3 method for class 'TSestModelEstEval':
roots(obj, criterion.args=NULL, ...)
    ## S3 method for class 'TSmodelEstEval':
roots(obj, criterion.args=list(randomize = TRUE), ...)

Arguments

obj
an object from which roots are to be extracted or calculated and printed.
criterion.args
arguments to be passed to this method when it is called by EstEval.
...
arguments to be passed to other methods.

concept

DSE

Details

The methods ***.ee are intended mainly to be called from EstEval as criterion for evaluating an estimation method.

See Also

roots stability EstEval