Learn R Programming

EvalEst (version 2015.4-2)

testEqual.EstEval: Specific Methods for Testing Equality

Description

See the generic function description.

Usage

"testEqual"(obj1, obj2, fuzz=0) "testEqual"(obj1, obj2, fuzz=1e-16)

Arguments

obj1
an object which is to be compared with the second object.
obj2
an object which is to be compared with the first object.
fuzz
tolerance for numerical comparisons. Values within fuzz will be considered equal.

See Also

testEqual