testEqual.EstEval: Specific Methods for Testing Equality
Description
See the generic function description.Usage
## S3 method for class 'EstEval':
testEqual(obj1, obj2, fuzz=0)
## S3 method for class 'MonteCarloSimulations':
testEqual(obj1, obj2, fuzz=1e-16)Arguments
obj1
an object which is to be compared with the second object.
obj2
an object which is to be compared with the first object.
fuzz
tolerance for numerical comparisons. Values within fuzz will be
considered equal.